@@ -1,5 +1,5 @@
 setOldClass("ModelFrame")
-setOldClass("ModelRecipe")
+setOldClass(c("ModelRecipe", "recipe"))
 setOldClass("Surv")
 setOldClass(c("SurvEvents", "SurvMatrix"))
 setOldClass(c("SurvProbs", "SurvMatrix"))
@@ -102,6 +102,21 @@ setClass("SVMTanhModelFit", contain = c("MLModelFit", "ksvm"))
 setClass("CForestModelFit", contains = c("MLModelFit", "RandomForest"))
 
 
+MLModelFunction <- setClass("MLModelFunction",
+  contains = "function"
+)
+
+
+"MLModelFunction<-" <- function(object, value) {
+  do.call(MLModelFunction, c(object, value))
+}
+
+
+MLModelList <- setClass("MLModelList",
+  contains = "list"
+)
+
+
 setClass("Calibration",
   slots = c(smoothed = "logical"),
   contains = "data.frame"
@@ -165,14 +180,20 @@ PerformanceDiffTest <- setClass("PerformanceDiffTest",
 )
 
 
-setClass("MLModelTune",
+MLModelTune <- setClass("MLModelTune",
   slots = c(tune_grid = "data.frame",
             performance = "Performance",
-            selected = "numeric"),
+            selected = "list",
+            metric = "MLMetric"),
   contains = "MLModel"
 )
 
 
+RecipeGrid <- setClass("RecipeGrid",
+  contains = "data.frame"
+)
+
+
 setClass("Resamples",
   slots = c(control = "MLControl",
             strata = "character"),
@@ -180,6 +201,13 @@ setClass("Resamples",
 )
 
 
+setClass("TunedRecipe",
+  slots = c(grid = "RecipeGrid",
+            params = "list"),
+  contains = "ModelRecipe"
+)
+
+
 setClass("VarImp",
   slots = c(center = "numeric", scale = "numeric"),
   contains = "data.frame"
