@@ -1,36 +1,35 @@
 #' Resampling Controls
 #' 
-#' @description
-#' The base \code{MLControl} constructor initializes a set of control parameters
-#' that are common to all resampling methods.
+#' Structures to define and control sampling methods for estimating predictive
+#' performance of models in the \pkg{MachineShop} package.
 #' 
+#' @name MLControl
 #' @rdname MLControl
+#' @aliases controls
 #' 
+#' @param folds number of cross-validation folds (K).
+#' @param prop proportion of cases to include in the training set
+#'   (\code{0 < prop < 1}).
+#' @param repeats number of repeats of the K-fold partitioning.
+#' @param samples number of bootstrap samples.
+#' @param seed integer to set the seed at the start of resampling.
 #' @param times,dist,method arguments passed to \code{\link{predict}}.
-#' @param seed integer to set the seed at the start of resampling.  This is set
-#' to a random integer by default (NULL).
 #' @param ...  arguments passed to \code{MLControl}.
 #' 
 #' @return \code{MLControl} class object.
 #' 
-#' @seealso \code{\link{resample}}
+#' @seealso \code{\link{resample}}, \code{\link{tune}}
 #' 
-MLControl <- function(times = NULL, dist = NULL, method = NULL, seed = NULL,
-                      ...) {
-  if (is.null(seed)) seed <- sample.int(.Machine$integer.max, 1)
-  new("MLControl", times = times, dist = dist, method = method, seed = seed)
-}
+NULL
 
 
-#' @description
+#' @rdname MLControl
+#' 
+#' @details
 #' \code{BootControl} constructs an \code{MLControl} object for simple bootstrap
 #' resampling in which models are fit with bootstrap resampled training sets and
 #' used to predict the full data set (Efron and Tibshirani 1993).
 #' 
-#' @rdname MLControl
-#' 
-#' @param samples number of bootstrap samples.
-#' 
 #' @references
 #' Efron B and Tibshirani RJ (1993). An Introduction to the Bootstrap.
 #' Monographs on Statistics and Applied Probability 57. Boca Raton, Florida,
@@ -45,12 +44,12 @@ BootControl <- function(samples = 25, ...) {
 }
 
 
-#' @description
+#' @rdname MLControl
+#' 
+#' @details
 #' \code{BootOptimismControl} constructs an \code{MLControl} object for
 #' optimism-corrected bootstrap resampling (Efron and Gong 1983, Harrell et al. 1996).
 #' 
-#' @rdname MLControl
-#' 
 #' @references
 #' Efron B and Gong G (1983). A leisurely look at the bootstrap, the jackknife,
 #' and cross-validation. The American Statistician, 37 (1): 36-48.
@@ -68,17 +67,14 @@ BootOptimismControl <- function(samples = 25, ...) {
 }
 
 
-#' @description
+#' @rdname MLControl
+#' 
+#' @details
 #' \code{CVControl} constructs an \code{MLControl} object for repeated K-fold
 #' cross-validation (Kohavi 1995).  In this procedure, the full data set is
 #' repeatedly partitioned into K-folds.  Within a partitioning, prediction is
 #' performed on each of the K folds with models fit on all remaining folds.
 #' 
-#' @rdname MLControl
-#' 
-#' @param folds number of cross-validation folds (K).
-#' @param repeats number of repeats of the K-fold partitioning.
-#' 
 #' @references
 #' Kohavi R (1995). A Study of Cross-Validation and Bootstrap for Accuracy
 #' Estimation and Model Selection. In Proceedings of the 14th International
@@ -94,13 +90,13 @@ CVControl <- function(folds = 10, repeats = 1, ...) {
 }
 
 
-#' @description
+#' @rdname MLControl
+#' 
+#' @details
 #' \code{OOBControl} constructs an \code{MLControl} object for out-of-bootstrap
 #' resampling in which models are fit with bootstrap resampled training sets and
 #' used to predict the unsampled cases.
 #' 
-#' @rdname MLControl
-#' 
 #' @examples
 #' ## Out-of-bootstrap validation with 100 samples
 #' OOBControl(samples = 100)
@@ -110,14 +106,11 @@ OOBControl <- function(samples = 25, ...) {
 }
 
 
-#' @description
-#' \code{SplitControl} constructs an \code{MLControl} object for splitting data
-#' into a seperate trianing and test set (Hastie et al. 2009).
-#' 
 #' @rdname MLControl
 #' 
-#' @param prop proportion of cases to include in the training set
-#' (\code{0 < prop < 1}).
+#' @details
+#' \code{SplitControl} constructs an \code{MLControl} object for splitting data
+#' into a seperate trianing and test set (Hastie et al. 2009).
 #' 
 #' @references
 #' Hastie T, Tibshirani R, and Friedman J (2009). The Elements of Statistical
@@ -133,12 +126,12 @@ SplitControl <- function(prop = 2/3, ...) {
 }
 
 
-#' @description
+#' @rdname MLControl
+#' 
+#' @details
 #' \code{TrainControl} constructs an \code{MLControl} object for training and
 #' performance evaluation to be performed on the same training set (Efron 1986).
 #' 
-#' @rdname MLControl
-#' 
 #' @references
 #' Efron B (1986). How biased is the apparent error rate of a prediction rule?
 #' Journal of the American Statistical Association, 81 (394): 461-70.
@@ -150,3 +143,15 @@ SplitControl <- function(prop = 2/3, ...) {
 TrainControl <- function(...) {
   new("MLTrainControl", MLControl(...))
 }
+
+
+#' @rdname MLControl
+#' 
+#' @details
+#' The base \code{MLControl} constructor initializes a set of control parameters
+#' that are common to all resampling methods.
+#' 
+MLControl <- function(times = NULL, dist = NULL, method = NULL,
+                      seed = sample(.Machine$integer.max, 1), ...) {
+  new("MLControl", times = times, dist = dist, method = method, seed = seed)
+}
