@@ -7,18 +7,18 @@
 #' @param trace level of execution information to display.
 #' @param degree maximum degree of interaction.
 #' @param nprune maximum number of terms (including intercept) in the pruned
-#' model.
+#'   model.
 #' @param nfold number of cross-validation folds.
 #' @param ncross number of cross-validations if \code{nfold > 1}.
 #' @param stratify logical indicating whether to stratify cross-validation
-#' samples by the response levels.
+#'   samples by the response levels.
 #' 
 #' @details
 #' \describe{
-#' \item{Response Types:}{\code{factor}, \code{numeric}}
-#' \item{\link[=tune]{Automatic Tuning} Grid Parameters:}{
-#'   \code{nprune}, \code{degree}*
-#' }
+#'   \item{Response Types:}{\code{factor}, \code{numeric}}
+#'   \item{\link[=TunedModel]{Automatic Tuning} of Grid Parameters:}{
+#'     \code{nprune}, \code{degree}*
+#'   }
 #' }
 #' * included only in randomly sampled grid points
 #' 
@@ -40,8 +40,8 @@
 #' \code{\link{resample}}, \code{\link{tune}}
 #' 
 #' @examples
-#' modelfit <- fit(Species ~ ., data = iris, model = EarthModel())
-#' varimp(modelfit, metric = "nsubsets", scale = FALSE)
+#' model_fit <- fit(Species ~ ., data = iris, model = EarthModel)
+#' varimp(model_fit, metric = "nsubsets", scale = FALSE)
 #' 
 EarthModel <- function(pmethod = c("backward", "none", "exhaustive", "forward",
                                    "seqrep", "cv"),
@@ -89,3 +89,5 @@ EarthModel <- function(pmethod = c("backward", "none", "exhaustive", "forward",
   )
   
 }
+
+MLModelFunction(EarthModel) <- NULL
