@@ -4,27 +4,27 @@
 #' component-wise arbitrary base-learners, e.g., smoothing procedures, are
 #' utilized as additive base-learners.
 #' 
-#' @param family \code{\link[mboost]{Family}} object.  Set automatically
-#' according to the class type of the response variable.
+#' @param family optional \code{\link[mboost]{Family}} object.  Set
+#'   automatically according to the class type of the response variable.
 #' @param baselearner character specifying the component-wise
-#' \code{\link[mboost:baselearners]{base learner}} to be used.
+#'   \code{\link[mboost:baselearners]{base learner}} to be used.
 #' @param dfbase gobal degrees of freedom for P-spline base learners
-#' (\code{"bbs"}).
+#'   (\code{"bbs"}).
 #' @param mstop number of initial boosting iterations.
 #' @param nu step size or shrinkage parameter between 0 and 1.
 #' @param risk method to use in computing the empirical risk for each boosting
-#' iteration.
+#'   iteration.
 #' @param stopintern logical inidicating whether the boosting algorithm stops
-#' internally when the out-of-bag risk increases at a subsequent iteration.
+#'   internally when the out-of-bag risk increases at a subsequent iteration.
 #' @param trace logical indicating whether status information is printed during
-#' the fitting process.
+#'   the fitting process.
 #' 
 #' @details
 #' \describe{
-#' \item{Response Types:}{\code{binary}, \code{numeric}, \code{Surv}}
-#' \item{\link[=tune]{Automatic Tuning} Grid Parameters:}{
-#'   \code{mstop}
-#' }
+#'   \item{Response Types:}{\code{binary}, \code{numeric}, \code{Surv}}
+#'   \item{\link[=TunedModel]{Automatic Tuning} of Grid Parameters:}{
+#'     \code{mstop}
+#'   }
 #' }
 #' 
 #' Default values for the \code{NULL} arguments and further model details can be
@@ -39,7 +39,7 @@
 #' @examples
 #' library(MASS)
 #' 
-#' fit(type ~ ., data = Pima.tr, model = GAMBoostModel())
+#' fit(type ~ ., data = Pima.tr, model = GAMBoostModel)
 #'
 GAMBoostModel <- function(family = NULL,
                           baselearner = c("bbs", "bols", "btree", "bss", "bns"),
@@ -102,3 +102,5 @@ GAMBoostModel <- function(family = NULL,
   )
   
 }
+
+MLModelFunction(GAMBoostModel) <- NULL
