@@ -4,14 +4,14 @@
 #' 
 #' @param ncomp number of components to include in the model.
 #' @param scale logical indicating whether to scale the predictors by the
-#' sample standard deviation.
+#'   sample standard deviation.
 #' 
 #' @details
 #' \describe{
-#' \item{Response Types:}{\code{factor}, \code{numeric}}
-#' \item{\link[=tune]{Automatic Tuning} Grid Parameters:}{
-#'   \code{ncomp}
-#' }
+#'   \item{Response Types:}{\code{factor}, \code{numeric}}
+#'   \item{\link[=TunedModel]{Automatic Tuning} of Grid Parameters:}{
+#'     \code{ncomp}
+#'   }
 #' }
 #' 
 #' Further model details can be found in the source link below.
@@ -22,7 +22,7 @@
 #' \code{\link{tune}}
 #' 
 #' @examples
-#' fit(sale_amount ~ ., data = ICHomes, model = PLSModel())
+#' fit(sale_amount ~ ., data = ICHomes, model = PLSModel)
 #'
 PLSModel <- function(ncomp = 1, scale = FALSE) {
   
@@ -71,3 +71,5 @@ PLSModel <- function(ncomp = 1, scale = FALSE) {
   )
   
 }
+
+MLModelFunction(PLSModel) <- NULL
