@@ -3,21 +3,21 @@
 #' Performs quadratic discriminant analysis.
 #' 
 #' @param prior prior probabilities of class membership if specified or the
-#' class proportions in the training set otherwise.
+#'   class proportions in the training set otherwise.
 #' @param method type of mean and variance estimator.
 #' @param nu degrees of freedom for \code{method = "t"}.
 #' @param use type of parameter estimation to use for prediction.
 #' 
 #' @details
 #' \describe{
-#' \item{Response Types:}{\code{factor}}
+#'   \item{Response Types:}{\code{factor}}
 #' }
 #' 
 #' The \code{\link{predict}} function for this model additionally accepts the
 #' following argument.
 #' \describe{
-#' \item{\code{prior}}{prior class membership probabilities for prediction data
-#' if different from the training set.}
+#'   \item{\code{prior}}{prior class membership probabilities for prediction data
+#'     if different from the training set.}
 #' }
 #' 
 #' Default values for the \code{NULL} arguments and further model details can be
@@ -29,7 +29,7 @@
 #' \code{\link{fit}}, \code{\link{resample}}, \code{\link{tune}}
 #' 
 #' @examples
-#' fit(Species ~ ., data = iris, model = QDAModel())
+#' fit(Species ~ ., data = iris, model = QDAModel)
 #'
 QDAModel <- function(prior = NULL, method = c("moment", "mle", "mve", "t"),
                      nu = 5,
@@ -62,3 +62,5 @@ QDAModel <- function(prior = NULL, method = c("moment", "mle", "mve", "t"),
   )
   
 }
+
+MLModelFunction(QDAModel) <- NULL
