@@ -3,7 +3,7 @@
 #' Fit an \code{rpart} model.
 #' 
 #' @param minsplit minimum number of observations that must exist in a node in
-#' order for a split to be attempted.
+#'   order for a split to be attempted.
 #' @param minbucket minimum number of observations in any terminal node.
 #' @param cp complexity parameter.
 #' @param maxcompete number of competitor splits retained in the output.
@@ -12,14 +12,14 @@
 #' @param xval number of cross-validations.
 #' @param surrogatestyle controls the selection of a best surrogate.
 #' @param maxdepth maximum depth of any node of the final tree, with the root
-#' node counted as depth 0.
+#'   node counted as depth 0.
 #' 
 #' @details
 #' \describe{
-#' \item{Response Types:}{\code{factor}, \code{numeric}, \code{Surv}}
-#' \item{\link[=tune]{Automatic Tuning} Grid Parameters:}{
-#' \code{cp}
-#' }
+#'   \item{Response Types:}{\code{factor}, \code{numeric}, \code{Surv}}
+#'   \item{\link[=TunedModel]{Automatic Tuning} of Grid Parameters:}{
+#'     \code{cp}
+#'   }
 #' }
 #' 
 #' Further model details can be found in the source link below.
@@ -30,7 +30,7 @@
 #' \code{\link{resample}}, \code{\link{tune}}
 #' 
 #' @examples
-#' fit(Species ~ ., data = iris, model = RPartModel())
+#' fit(Species ~ ., data = iris, model = RPartModel)
 #'
 RPartModel <- function(minsplit = 20, minbucket = round(minsplit / 3),
                        cp = 0.01, maxcompete = 4, maxsurrogate = 5,
@@ -75,3 +75,5 @@ RPartModel <- function(minsplit = 20, minbucket = round(minsplit / 3),
   )
   
 }
+
+MLModelFunction(RPartModel) <- NULL
