@@ -2,21 +2,20 @@
 #' 
 #' Fit a super learner model to predictions from multiple base learners.
 #' 
-#' @param ... \code{MLModel} functions, function names, objects, or lists of
-#' these to serve as base learners.
-#' @param model \code{MLModel} object, constructor function, or character string
-#' naming a constructor function to serve as the super model.
-#' @param control \code{\link{MLControl}} object, control function, or character
-#' string naming a control function defining the resampling method to be
-#' employed for the estimation of base learner weights.
+#' @param ... \link[=models]{model} functions, function names, calls, or vector
+#'   of these to serve as base learners.
+#' @param model \link[=models]{model} function, function name, or call defining
+#'   the super model.
+#' @param control \link[=controls]{control} function, function name, or call
+#'   defining the resampling method to be employed for the estimation of base
+#'   learner weights.
 #' @param all_vars logical indicating whether to include the original
-#' predictor variables in the super model.
+#'   predictor variables in the super model.
 #' 
 #' @details
 #' \describe{
-#' \item{Response Types:}{\code{factor}, \code{numeric}, \code{ordered},
-#' \code{Surv}
-#' }
+#'   \item{Response Types:}{\code{factor}, \code{numeric}, \code{ordered},
+#'     \code{Surv}}
 #' }
 #' 
 #' @return \code{SuperModel} class object that inherits from \code{MLModel}.
@@ -30,10 +29,11 @@
 #' 
 #' @examples
 #' model <- SuperModel(GBMModel, SVMRadialModel, GLMNetModel(lambda = 0.01))
-#' modelfit <- fit(sale_amount ~ ., data = ICHomes, model = model)
-#' predict(modelfit, newdata = ICHomes)
+#' model_fit <- fit(sale_amount ~ ., data = ICHomes, model = model)
+#' predict(model_fit, newdata = ICHomes)
 #' 
-SuperModel <- function(..., model = GBMModel, control = CVControl,
+SuperModel <- function(..., model = GBMModel,
+                       control = MachineShop::settings("control"),
                        all_vars = FALSE) {
   
   base_learners <- lapply(unlist(list(...)), getMLObject, class = "MLModel")
@@ -63,6 +63,8 @@ SuperModel <- function(..., model = GBMModel, control = CVControl,
 
 }
 
+MLModelFunction(SuperModel) <- NULL
+
 
 .fit.SuperModel <- function(model, x, ...) {
   mf <- ModelFrame(x, na.rm = FALSE)
