@@ -6,10 +6,30 @@
 #' @rdname fit-methods
 #' 
 #' @param x defines a relationship between model predictor and response
-#' variables.  May be a \code{formula}, design matrix of predictors,
-#' \code{ModelFrame}, or untrained \code{recipe}.
+#'   variables.  May be a \code{\link{formula}}, design \code{\link{matrix}} of
+#'   predictors, \code{\link{ModelFrame}}, untrained
+#'   \code{\link[recipes]{recipe}}, or \code{\link{TunedRecipe}} object.
+#'   Alternatively, a \link[=models]{model} function or call may be given first
+#'   followed by objects defining the predictor and response relationship.
+#' @param y response variable.
+#' @param data \link[=data.frame]{data frame} containing observed predictors and
+#'   outcomes.
+#' @param model \link[=models]{model} function, function name, or call.
 #' @param ... arguments passed to other methods.
 #' 
+#' @return \code{MLModelFit} class object.
+#' 
+#' @seealso \code{\link{response}}, \code{\link{predict}}, \code{\link{varimp}}
+#' 
+#' @examples
+#' ## Survival response example
+#' library(survival)
+#' library(MASS)
+#' 
+#' gbm_fit <- fit(Surv(time, status != 2) ~ sex + age + year + thickness + ulcer,
+#'                data = Melanoma, model = GBMModel)
+#' varimp(gbm_fit)
+#' 
 fit <- function(x, ...) {
   UseMethod("fit")
 }
@@ -17,25 +37,6 @@ fit <- function(x, ...) {
 
 #' @rdname fit-methods
 #' 
-#' @param data \code{data.frame} containing observed predictors and outcomes.
-#' @param model \code{MLModel} object, constructor function, or character string
-#' naming a constructor function that returns an \code{MLModel} object.
-#' 
-#' @return \code{MLModelFit} class object.
-#' 
-#' @seealso \code{\link{ModelFrame}}, \code{\link[recipes]{recipe}},
-#' \code{\link{models}}, \code{\link{tune}}, \code{\link{predict}},
-#' \code{\link{varimp}}
-#' 
-#' @examples
-#' ## Survival response example
-#' library(survival)
-#' library(MASS)
-#' 
-#' gbmfit <- fit(Surv(time, status != 2) ~ sex + age + year + thickness + ulcer,
-#'               data = Melanoma, model = GBMModel)
-#' varimp(gbmfit)
-#' 
 fit.formula <- function(x, data, model, ...) {
   fit(ModelFrame(x, data, na.rm = FALSE), model)
 }
@@ -43,8 +44,6 @@ fit.formula <- function(x, data, model, ...) {
 
 #' @rdname fit-methods
 #' 
-#' @param y predictor variable.
-#' 
 fit.matrix <- function(x, y, model, ...) {
   fit(ModelFrame(x, y, na.rm = FALSE), model)
 }
@@ -53,9 +52,9 @@ fit.matrix <- function(x, y, model, ...) {
 #' @rdname fit-methods
 #' 
 #' @details
-#' User-specified case weights may be specified for
-#' \code{\link[=ModelFrame]{ModelFrames}} upon creation with the \code{weights}
-#' argument in its constructor.
+#' User-specified case weights may be specified for \code{ModelFrames} upon
+#' creation with the \code{\link[=ModelFrame]{weights}} argument in its
+#' constructor.
 #' 
 fit.ModelFrame <- function(x, model, ...) {
   .fit(getMLObject(model, "MLModel"), x)
@@ -69,7 +68,28 @@ fit.ModelFrame <- function(x, model, ...) {
 #' "case_weight" \code{\link[recipes:roles]{role}} for them.
 #' 
 fit.recipe <- function(x, model, ...) {
-  .fit(getMLObject(model, "MLModel"), prep(ModelRecipe(x)))
+  x <- if (is(x, "TunedRecipe")) {
+    params <- as(x, "list")
+    params$model <- model
+    do.call(tune_recipe, c(list(as(x, "ModelRecipe")), params))
+  } else {
+    ModelRecipe(x)
+  }
+  .fit(getMLObject(model, "MLModel"), prep(x))
+}
+
+
+#' @rdname fit-methods
+#' 
+fit.MLModel <- function(x, ...) {
+  fit(..., model = x)
+}
+
+
+#' @rdname fit-methods
+#' 
+fit.MLModelFunction <- function(x, ...) {
+  fit(..., model = x)
 }
 
 
