@@ -13,7 +13,7 @@ predict.Surv <- function(object, x, ...) {
 
 .predict.Surv.list <- function(y, object, times, dist, ...) {
   if (length(times)) {
-    dist <- surv_dist(dist)
+    dist <- surv_dist_probs(dist)
     t(sapply(object, function(x) predict(dist(x), times)))
   } else {
     dist <- surv_dist_mean(dist)
@@ -26,7 +26,7 @@ predict.Surv <- function(object, x, ...) {
 .predict.Surv.matrix <- function(y, object, times, dist, ...) {
   x <- SurvProbs(object, y[, "time"])
   if (length(times)) {
-    predict(surv_dist(dist)(x), times)
+    predict(surv_dist_probs(dist)(x), times)
   } else {
     mean(surv_dist_mean(dist)(x))
   }
@@ -37,7 +37,7 @@ predict.Surv <- function(object, x, ...) {
   risk <- exp(object)
   new_risk <- exp(new_lp)
   if (length(times)) {
-    predict(surv_dist(dist)(y, risk, ...), times, new_risk)
+    predict(surv_dist_probs(dist)(y, risk, ...), times, new_risk)
   } else {
     mean(surv_dist_mean(dist)(y, risk, ...), new_risk)
   }
@@ -57,12 +57,13 @@ EmpiricalSurv.default <- function(x, ...) {
 }
 
 
-EmpiricalSurv.Surv <- function(y, risk = NULL,
-                               method = c("efron", "breslow",
-                                          "fleming-harrington"), ...) {
+EmpiricalSurv.Surv <- function(y, risk = NULL, method =
+                                 c("breslow", "efron", "fleming-harrington"),
+                               ...) {
   times <- y[, "time"]
   events <- pmin(y[, "status"], 1)
   if (is.null(risk)) risk <- rep(1, length(times))
+  if (is.null(method)) method <- MachineShop::settings("method.EmpiricalSurv")
   surv <- switch(match.arg(method),
                  "breslow" = empiricalsurv_breslow,
                  "efron" = empiricalsurv_efron,
@@ -262,15 +263,15 @@ SurvMatrix <- function(object, times = NULL) {
 #' @rdname SurvMatrix
 #' 
 #' @param object matrix, or object that can be converted to one, of predicted
-#' survival events or probabilities with columns and rows representing
-#' prediction times and cases, respectively.
+#'   survival events or probabilities with columns and rows representing
+#'   prediction times and cases, respectively.
 #' @param times numeric vector of the survival prediction times.
 #' 
 #' @return Object that is of the same class as the constructor name and inherits
 #' from \code{SurvMatrix}.  Examples of these objects are the predicted survival
-#' events and probabilities returned by the \code{predict} function.
+#' events and probabilities returned by the \link{predict} function.
 #' 
-#' @seealso \code{\link{metrics}}, \code{\link{predict}}
+#' @seealso \code{\link{performance}}, \code{\link{metrics}}
 #' 
 SurvEvents <- function(object = numeric(), times = NULL) {
   object <- SurvMatrix(object, times)
@@ -316,15 +317,20 @@ surv_cases <- function(..., subset = TRUE) {
 surv_dist <- function(x = c("empirical", "exponential", "rayleigh",
                             "weibull")) {
   switch(match.arg(x),
+         "empirical" = EmpiricalSurv,
          "exponential" = Exponential,
          "rayleigh" = Rayleigh,
-         "weibull" = Weibull,
-         EmpiricalSurv)
+         "weibull" = Weibull)
 }
 
 
 surv_dist_mean <- function(x = NULL) {
-  if (is.null(x)) Weibull else surv_dist(x)
+  surv_dist(if (is.null(x)) MachineShop::settings("dist.Surv") else x)
+}
+
+
+surv_dist_probs <- function(x = NULL) {
+  surv_dist(if (is.null(x)) MachineShop::settings("dist.SurvProbs") else x)
 }
 
 
